==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/System.Drawing/System.Drawing/BufferedGraphicsContext.cs <==
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Authors:
//
//   Jordi Mas i Hernandez <jordimash@gmail.com>
//
//

#if NET_2_0

using System;
using System.Runtime.Serialization;
using System.Runtime.InteropServices;
using System.ComponentModel;

namespace System.Drawing
{
	public sealed class BufferedGraphicsContext : IDisposable
	{
		private Size max_buffer;

		public BufferedGraphicsContext ()
		{
			max_buffer = Size.Empty;
		}

		~BufferedGraphicsContext ()
		{
			
		}

		public BufferedGraphics Allocate (Graphics targetGraphics, Rectangle targetRectangle)
		{
			BufferedGraphics graphics = new BufferedGraphics (targetGraphics, targetRectangle);
			return graphics;			
		}

		[MonoTODO]
		public BufferedGraphics Allocate (IntPtr targetDC, Rectangle targetRectangle)
		{
			throw new NotImplementedException ();
		}

		public void Dispose ()
		{			
			System.GC.SuppressFinalize (this);
		}

		public void Invalidate ()
		{
			
		}

		public Size MaximumBuffer {
			get {return max_buffer; }
			set {
				if (value.Width <= 0 || value.Height <= 0) {
					throw new ArgumentException ("The height or width of the size is less than or equal to zero.");
				}

				max_buffer = value;
			}
		}

	}
}

#endif

==> mono_4.6.2.7+dfsg.orig.tar.gz: mono-4.6.2+dfsg/mcs/class/System.Drawing/System.Drawing/BufferedGraphicsContext.cs <==
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Authors:
//
//   Jordi Mas i Hernandez <jordimash@gmail.com>
//
//


using System.ComponentModel;
using System.Runtime.InteropServices;
using System.Runtime.Serialization;
using System.Security.Permissions;

namespace System.Drawing
{
	public sealed class BufferedGraphicsContext : IDisposable
	{
		private Size max_buffer;

		public BufferedGraphicsContext ()
		{
			max_buffer = Size.Empty;
		}

		~BufferedGraphicsContext ()
		{
		}

		public BufferedGraphics Allocate (Graphics targetGraphics, Rectangle targetRectangle)
		{
			BufferedGraphics graphics = new BufferedGraphics (targetGraphics, targetRectangle);
			return graphics;			
		}

		[MonoTODO ("The targetDC parameter has no equivalent in libgdiplus.")]
		[SecurityPermission (SecurityAction.Demand, UnmanagedCode = true)]
		public BufferedGraphics Allocate (IntPtr targetDC, Rectangle targetRectangle)
		{
			throw new NotImplementedException ();
		}

		public void Dispose ()
		{			
			System.GC.SuppressFinalize (this);
		}

		public void Invalidate ()
		{
		}

		public Size MaximumBuffer {
			get {return max_buffer; }
			set {
				if (value.Width <= 0 || value.Height <= 0) {
					throw new ArgumentException ("The height or width of the size is less than or equal to zero.");
				}

				max_buffer = value;
			}
		}

	}
}
